controller

package
v0.0.0-...-1fd6b9d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2021 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Addser

func Addser(c *gin.Context)

func Del

func Del(c *gin.Context)

func GetTerm

func GetTerm(c *gin.Context)

func Info

func Info(c *gin.Context)

func Login

func Login(c *gin.Context)

func ResetPass

func ResetPass(c *gin.Context)

func Send

func Send(c *gin.Context)

func Sftp_ssh

func Sftp_ssh(c *gin.Context)

func UpdataNick

func UpdataNick(c *gin.Context)

func WsSsh

func WsSsh(c *gin.Context)

WsSsh handle webSocket connection. first,we establish a ssh connection to ssh server when a webSocket comes; then we deliver ssh data via ssh connection between browser and ssh server. That is, read webSocket data from browser (e.g. 'ls' command) and send data to ssh server via ssh connection; the other hand, read returned ssh data from ssh server and write back to browser via webSocket API.

Types

type AuthMsg

type AuthMsg struct {
	Type  string `json:"type"`
	Token string `json:"token"`
}

Directories

Path Synopsis

Jump to